@@ -5,9 +5,6 @@ Description of what this model does
 """
 import os
 import sys
-import inspect
-import dataclasses
-from typing import Dict, Optional, Tuple, Type, Any
 
 from sklearn.neural_network import MLPClassifier
 from sklearn.neighbors import KNeighborsClassifier
@@ -63,7 +60,6 @@ from dffml_model_scikit.scikit_base import (
     ScikitContextUnsprvised,
 )
 from dffml.feature.feature import Feature, Features, DefFeature
-from dffml.util.cli.parser import list_action
 
 
 def applicable_features(self, features):
@@ -218,7 +214,7 @@ for entry_point_name, name, cls, applicable_features_function in [
         config_fields["tcluster"] = (
             Feature,
             field(
-                "True cluster labelfor evaluating clustering models",
+                "True cluster label for evaluating clustering models",
                 default=None,
             ),
         )
@@ -245,8 +241,8 @@ for entry_point_name, name, cls, applicable_features_function in [
         dffml_config_properties["predict"] = (
             Feature,
             field(
-                "field here for compability with other functions,no need to change",
-                default=DefFeature(name="Prediction", dtype="str", length=10),
+                "Name used as meaning of prediction",
+                default=DefFeature(name="cluster", dtype="str", length=10),
             ),
         )
 
